<?php
/**
 * Custom Customize API: Manta_Unit_Control class
 *
 * @package	 Manta
 * @since 1.0.0
 */

/**
 * Customize Custom unit control class.
 *
 * @since 1.0.0
 */
class Manta_Unit_Control extends WP_Customize_Control {

	/**
	 * Type.
	 *
	 * @access public
	 * @var string
	 */
	public $type = 'number';

	/**
	 * Default
	 *
	 * @access public
	 * @var string
	 */
	public $default_value = '';

	/**
	 * Unit
	 *
	 * @access public
	 * @var string
	 */
	public $unit = '';

	/**
	 * Convert option data in JSON.
	 *
	 * @since 1.1
	 */
	public function to_json() {
		parent::to_json();
		$this->json['id']          = $this->id;
		$this->json['unit']        = $this->unit;
		$this->json['link']        = $this->get_link();
		$this->json['value']       = $this->value();
		$this->json['default']     = $this->default_value;
		$this->json['reset_title'] = esc_attr_x( 'Reset', 'Reset the Unit customizer control value.', 'manta' );
	}

	/**
	 * Content template to unit control.
	 *
	 * @since 1.0.0
	 */
	public function content_template() {
		?>
		<label>
			<p>
				<span class="customize-control-title">{{ data.label }}</span>
				<span class="value">
					<input name="{{ data.id }}" type="number" {{{ data.link }}} value="{{{ data.value }}}" class="unit-input" min="{{data.min}}" max="{{data.max}}" step="{{data.step}}" />
					<span class="px">px</span>
				</span>
			</p>
		</label>
		<span title="{{ data.reset_title }}" class="manta-unit-default-value" data-default-value="{{ data.default }}">
			<span class="dashicons dashicons-image-rotate" aria-hidden="true"></span>
			<span class="screen-reader-text">{{ data.reset_title }}</span>
		</span>
		<?php
	}
}
